@@ -181,7 +181,7 @@
     <message>
         <location filename="../mainwindow.ui" line="523"/>
         <source>Format</source>
-        <translation type="unfinished"/>
+        <translation>Формат</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="533"/>
@@ -262,7 +262,7 @@
     <message>
         <location filename="../mainwindow.ui" line="773"/>
         <source>Encrypt</source>
-        <translation type="unfinished"/>
+        <translation>Шифрування</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="780"/>
@@ -272,7 +272,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="76"/>
         <source>Confirmation</source>
-        <translation type="unfinished"/>
+        <translation>Підтвердження</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="77"/>
@@ -344,7 +344,7 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../mainwindow.cpp" line="399"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>Про %1</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="400"/>
@@ -364,12 +364,12 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../mainwindow.cpp" line="404"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>%1 Ліцензія</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="411"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>%1 Довідка</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="419"/>
@@ -466,7 +466,7 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../main.cpp" line="78"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
-        <translation type="unfinished"/>
+        <translation>Здається, ви ввійшли як root, вийдіть із системи та увійдіть як звичайний користувач, щоб використовувати цю програму.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="91"/>
